@@ -96,14 +96,14 @@ class ESSearchResponse(object):
     def total(self):
         return self.hit_stats.get('total', 0)
 
-    def results(self, paginate=True):
+    def results(self, paginate=True, just_source=True):
         if paginate:
             paginator = ESPaginator(
                 self.hit_data,
                 self.page_size,
                 count=self.total()
             )
-            return paginator.page(self.page)
+            return paginator.page(self.page, just_source)
 
         return self.hit_data
 
